==> kuzu-0.6.1.tar.gz: sdist/kuzu-source/src/include/planner/operator/logical_cross_product.h <==
#pragma once

#include "common/enums/accumulate_type.h"
#include "planner/operator/logical_operator.h"
#include "planner/operator/sip/side_way_info_passing.h"

namespace kuzu {
namespace planner {

class LogicalCrossProduct : public LogicalOperator {
    static constexpr LogicalOperatorType type_ = LogicalOperatorType::CROSS_PRODUCT;

public:
    LogicalCrossProduct(common::AccumulateType accumulateType,
        std::shared_ptr<binder::Expression> mark, std::shared_ptr<LogicalOperator> probeChild,
        std::shared_ptr<LogicalOperator> buildChild)
        : LogicalOperator{type_, std::move(probeChild), std::move(buildChild)},
          accumulateType{accumulateType}, mark{std::move(mark)} {}

    void computeFactorizedSchema() override;
    void computeFlatSchema() override;

    std::string getExpressionsForPrinting() const override { return std::string(); }

    common::AccumulateType getAccumulateType() const { return accumulateType; }
    bool hasMark() const { return mark != nullptr; }
    std::shared_ptr<binder::Expression> getMark() const { return mark; }

    SIPInfo& getSIPInfoUnsafe() { return sipInfo; }
    SIPInfo getSIPInfo() const { return sipInfo; }

    std::unique_ptr<LogicalOperator> copy() override {
        auto op = make_unique<LogicalCrossProduct>(accumulateType, mark, children[0]->copy(),
            children[1]->copy());
        op->sipInfo = sipInfo;
        return op;
    }

private:
    common::AccumulateType accumulateType;
    std::shared_ptr<binder::Expression> mark;
    SIPInfo sipInfo;
};

} // namespace planner
} // namespace kuzu

==> kuzu-0.6.2.dev4.tar.gz: sdist/kuzu-source/src/include/planner/operator/logical_cross_product.h <==
#pragma once

#include "common/enums/accumulate_type.h"
#include "planner/operator/logical_operator.h"
#include "planner/operator/sip/side_way_info_passing.h"

namespace kuzu {
namespace planner {

class LogicalCrossProduct : public LogicalOperator {
    static constexpr LogicalOperatorType type_ = LogicalOperatorType::CROSS_PRODUCT;

public:
    LogicalCrossProduct(common::AccumulateType accumulateType,
        std::shared_ptr<binder::Expression> mark, std::shared_ptr<LogicalOperator> probeChild,
        std::shared_ptr<LogicalOperator> buildChild, std::unique_ptr<OPPrintInfo> printInfo)
        : LogicalOperator{type_, std::move(probeChild), std::move(buildChild), printInfo->copy()},
          accumulateType{accumulateType}, mark{std::move(mark)} {}

    void computeFactorizedSchema() override;
    void computeFlatSchema() override;

    std::string getExpressionsForPrinting() const override { return std::string(); }

    common::AccumulateType getAccumulateType() const { return accumulateType; }
    bool hasMark() const { return mark != nullptr; }
    std::shared_ptr<binder::Expression> getMark() const { return mark; }

    SIPInfo& getSIPInfoUnsafe() { return sipInfo; }
    SIPInfo getSIPInfo() const { return sipInfo; }

    std::unique_ptr<LogicalOperator> copy() override {
        auto op = make_unique<LogicalCrossProduct>(accumulateType, mark, children[0]->copy(),
            children[1]->copy(), printInfo->copy());
        op->sipInfo = sipInfo;
        return op;
    }

private:
    common::AccumulateType accumulateType;
    std::shared_ptr<binder::Expression> mark;
    SIPInfo sipInfo;
};

} // namespace planner
} // namespace kuzu
